pub struct IdentityLockboxRef(/* private fields */);Expand description
An encrypted IdentityKey.
This must be decrypted by the matching recipient, which will return the IdentityKey on
success. It can either be decrypted on its own, returning a temporary IdentityKey, or
through a Vault, which will store the IdentityKey.
This is only a reference to an encrypted payload. The owned version is IdentityLockbox.
See: StreamKey::decrypt_identity_key,
LockKey::decrypt_identity_key, and
Vault::decrypt_identity_key.
Example
Using a StreamKey for decryption:
// We have `enc`, a byte vector containing a lockbox
let dec_lockbox: &IdentityLockboxRef = IdentityLockboxRef::from_bytes(&enc[..])?;
let recipient: LockboxRecipient = dec_lockbox.recipient();
// ...
// Retrieve the key by looking up recipient
// ...
let dec_key: IdentityKey = key.decrypt_identity_key(&dec_lockbox)?;Implementations
Sourceimpl IdentityLockboxRef
impl IdentityLockboxRef
Sourcepub fn as_parts(&self) -> LockboxParts<'_>
pub fn as_parts(&self) -> LockboxParts<'_>
Decompose the lockbox into its component parts.
Sourcepub fn recipient(&self) -> LockboxRecipient
pub fn recipient(&self) -> LockboxRecipient
Get the target recipient who can decrypt this.
pub fn from_bytes(buf: &[u8]) -> Result<&IdentityLockboxRef, CryptoError>