pub struct StreamLockboxRef(/* private fields */);Expand description
An encrypted StreamKey.
This must be decrypted by the matching recipient, which will return the StreamKey on
success. It can either be decrypted on its own, returning a temporary StreamKey, or
through a Vault, which will store the StreamKey.
This is only a reference to an encrypted payload. The owned version is StreamLockbox.
See: StreamKey::decrypt_stream_key,
LockKey::decrypt_stream_key, and
Vault::decrypt_stream_key.
Example
Using a StreamKey for decryption (different from the one contained in the lockbox!):
// We have `enc`, a byte vector containing a lockbox
let dec_lockbox: &StreamLockboxRef = StreamLockboxRef::from_bytes(&enc[..])?;
let recipient: LockboxRecipient = dec_lockbox.recipient();
// ...
// Retrieve the key by looking up recipient
// ...
let dec_key: StreamKey = key.decrypt_stream_key(&dec_lockbox)?;Implementations
Sourceimpl StreamLockboxRef
impl StreamLockboxRef
Sourcepub fn as_parts(&self) -> LockboxParts<'_>
pub fn as_parts(&self) -> LockboxParts<'_>
Decompose the lockbox into its component parts.
Sourcepub fn recipient(&self) -> LockboxRecipient
pub fn recipient(&self) -> LockboxRecipient
Get the target recipient who can decrypt this.
pub fn from_bytes(buf: &[u8]) -> Result<&StreamLockboxRef, CryptoError>