Serialized data associated with a parent Document and key string.
Entries are created by calling NewEntry::new with serializable data, the hash of the parent
document, and the key string. Once created, they can be signed and have their compression
settings chosen. Entries (new or otherwise) are verified and encoded using a
Schema, which should match the schema used by the parent document.
Structs
- Entry
- Holds serialized data associated with a parent document and a key string.
- Entry
Ref - A reference triplet to an
Entry, containing the hash of the entry’s parent document, the key string for the entry, and the hash of the entry itself. Note that the entry hash is still formed in a way the includes the parent & key, so changing either means the entry hash would also change. - NewEntry
- A new Entry that has not yet been validated.